<?php
namespace Drupal\fixed_block_content\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\fixed_block_content\Entity\FixedBlockContent;
use Drupal\Core\Cache\Cache;

/**
 * Provides a fixed content block placement.
 *
 * @Block(
 *   id = "fixed_block_content",
 *   admin_label = @Translation("Fixed custom block"),
 *   category = @Translation("Fixed custom"),
 *   deriver = "Drupal\fixed_block_content\Plugin\Derivative\FixedBlockContent"
 * )
 */
class FixedBlockContentBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a FixedBlockContentBlock object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $output = [];

    if (($fixed_block = FixedBlockContent::load($this->getDerivativeId()))
      && ($block_content = $fixed_block->getBlockContent())) {
      $output = $this->entityTypeManager
        ->getViewBuilder('block_content')
        ->view($block_content);
    }

    return $output;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() {
    $cache_tags = parent::getCacheTags();
    /** @var \Drupal\fixed_block_content\FixedBlockContentInterface $fixed_block */
    if ($fixed_block = FixedBlockContent::load($this->getDerivativeId())) {
      $cache_tags = Cache::mergeTags($cache_tags, $fixed_block->getCacheTags());
      $cache_tags = Cache::mergeTags($cache_tags, $fixed_block->getBlockContent()->getCacheTags());
    }

    return $cache_tags;
  }

}
